==> haskell-executable-path-0.0.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-F9Q9fx6ZcUmKZL73rDtJHj
key: executable-path-0.0.3.1-F9Q9fx6ZcUmKZL73rDtJHj
license: PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
author: Balazs Komuves
exposed: True
indefinite: False
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
abi: 08d0b4a274b8781449241951ac6305df
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-F9Q9fx6ZcUmKZL73rDtJHj
depends:
    base-4.10.0.0 directory-1.3.0.2 filepath-1.4.1.2 unix-2.7.2.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             unix-2.7.2.2=7af8630098b53e228272ffaea5bacf62
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-executable-path-0.0.3.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-AfkFEaU14vmFFo5TMHgBXI
key: executable-path-0.0.3.1-AfkFEaU14vmFFo5TMHgBXI
license: PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
author: Balazs Komuves
exposed: True
indefinite: False
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
abi: 8c79c67750ca090c7f052cfe029b123b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-AfkFEaU14vmFFo5TMHgBXI
depends:
    base-4.10.1.0 directory-1.3.0.2 filepath-1.4.1.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
